from herre.wards.graphql import ParsedQuery


GET_WHALE = ParsedQuery(
    """
query Whale($id: ID, $template: ID){
  whale(id: $id, template: $template){
    id
    template
    githubrepo {
      user
      branch
      repo
      id
    }
    config
  }
}
"""
)


GET_GITHUBREPO = ParsedQuery(
    """
query GithubRepo($id: ID, $template: ID){
  githubRepo(id: $id){
    id
    user
    branch
    repo
  }
}
"""
)



import argparse
from enum import Enum
from herre import Herre
from rich.console import Console
from rich.prompt import Prompt, Confirm
import os
import asyncio

directory = os.getcwd()


class KuayOptions(str, Enum):
    INIT = "init"
    DEPLOY = "dev"


def main(
    script=KuayOptions.INIT,
    name=None,
    path=".",
):

    console = Console()

    if path == ".":
        app_directory = os.getcwd()
        name = name or os.path.basename(app_directory)
    else:
        app_directory = os.path.join(os.getcwd(), path)
        name = name or path

    fakts_path = os.path.join(app_directory, "fakts.yaml")
    run_script_path = os.path.join(app_directory, "run.py")

    if script == KuayOptions.DEPLOY:

        if not os.path.isfile(run_script_path):
            console.print(f"Could't find a run.py in {app_directory} {run_script_path}")
            return
        if not os.path.isfile(fakts_path):
            console.print(f"{app_directory} does not have a valid fakts.yaml")
            return

    if script == KuayOptions.INIT:

        console.print("Initializing Arkitekt Started. Lets do this!")

        if not os.path.isfile(fakts_path):
            console.print(
                f"There seems to have been a previous App initialized at {app_directory}"
            )
            return


def entrypoint():
    parser = argparse.ArgumentParser(description="Say hello")
    parser.add_argument("script", type=KuayOptions, help="The Script Type")
    parser.add_argument("path", type=str, help="The Script Type")
    args = parser.parse_args()

    main(
        script=args.script,
        path=args.path,
    )


if __name__ == "__main__":
    entrypoint()



from fakts import Config
from herre.wards.query import TypedQuery
from herre.wards.graphql import GraphQLWard


class PortConfig(Config):
    host: str
    port: int
    secure: bool

    class Config:
        group = "port"
        env_prefix = "port_"

    @property
    def endpoint(self):
        return f"http://{self.host}:{self.port}/graphql"


class PortWard(GraphQLWard):
    configClass = PortConfig

    class Meta:
        key = "port"


class gql(TypedQuery):
    ward_key = "port"



from typing import Optional
from .ward import *
from herre.access.model import GraphQLModel
from kuay.graphql.queries.whale import GET_WHALE


class GithubRepo(GraphQLModel):
    user: Optional[str]
    repo: Optional[str]
    branch: Optional[str]

    class Meta:
        identifier = "githubrepo"
        ward = "port"
        get = GET_WHALE


class Whale(GraphQLModel):
    githubrepo: Optional[GithubRepo]
    template: Optional[str]
    image: Optional[str]
    config: Optional[dict]

    class Meta:
        identifier = "whale"
        ward = "port"
        get = GET_WHALE



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['kuay', 'kuay.cli', 'kuay.graphql', 'kuay.graphql.queries']

package_data = \
{'': ['*']}

install_requires = \
['herre>=0.1.55,<0.2.0']

entry_points = \
{'console_scripts': ['kuay = kuay.cli.main:entrypoint']}

setup_kwargs = {
    'name': 'kuay',
    'version': '0.1.19',
    'description': '',
    'long_description': None,
    'author': 'jhnnsrs',
    'author_email': 'jhnnsrs@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
